diff --git a/Load.py b/Load.py
index df5bef2d7ea7a0eea2e892f48bd5c45c1049892b..fc98780af29f0d257e33d033f0913bdf23c16f3c 100644
--- a/Load.py
+++ b/Load.py
@@ -421,7 +421,7 @@ def load(fields, runNB, proposalNB, subFolder='raw', display=False, validate=Fal
             subFolder: (str) sub-folder from which to load the data. Use 'raw' for raw
                 data or 'proc' for processed data.
             display: (bool) whether to show the run.info or not
             validate: (bool) whether to run karabo-data-validate or not
             subset: a subset of train that can be load with by_index[:5] for the
                 first 5 trains
             rois: a dictionnary of mnemonics with a list of rois definition and the desired
@@ -444,7 +444,7 @@ def load(fields, runNB, proposalNB, subFolder='raw', display=False, validate=Fal
     run = RunDirectory(runFolder).select_trains(subset)
 
     if validate:
-        get_ipython().system('karabo-data-validate ' + runFolder)
+        get_ipython().system('extra-data-validate ' + runFolder)
     if display:
         print('Loading data from {}'.format(runFolder))
         run.info()
@@ -421,7 +421,7 @@ def load(fields, runNB, proposalNB, subFolder='raw', display=False, validate=Fal
                 data or 'proc' for processed data.
             display: (bool) whether to show the run.info or not
-            validate: (bool) whether to run karabo-data-validate or not
+            validate: (bool) whether to run extra-data-validate or not
             subset: a subset of train that can be load with by_index[:5] for the
                 first 5 trains